@@ -6,7 +6,7 @@
 #### A novel, divergence based, regression for compositional data
 #### Proceedings of the 28th Panhellenic Statistics Conference
 ################################
-js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
+js.compreg <- function(y, x, con = TRUE, B = 1, ncores = 1, xnew = NULL) {
   ## y is dependent variable, the compositional data
   ## x is the independent variable(s)
   ## B is the number of bootstrap samples used to obtain
@@ -24,6 +24,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
   n <- dim(y)[1]  ## sample size
   x <- model.matrix(y ~ ., data.frame(x) )
+  if ( !con )  x <- x[, -1, drop = FALSE]
   p <- dim(x)[2]
   d <- dim(y)[2] - 1  ## dimensionality of the simplex
   namx <- colnames(x)
@@ -34,9 +35,8 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
   ## the next lines minimize the kl.compreg function and obtain the estimated betas
   runtime <- proc.time()
-  ini <- as.vector( t( kl.compreg(y, x[, -1, drop = FALSE])$be ) )
-  oop <- options(warn = -1)
-  on.exit( options(oop) )
+  ini <- as.vector( t( Compositional::kl.compreg(y, x[, -1, drop = FALSE], con = con)$be ) )
+  #suppressWarnings()
   qa <- nlm(jsreg, ini, y = y, x = x, d = d)
   qa <- nlm(jsreg, qa$estimate, y = y, x = x, d = d)
   qa <- nlm(jsreg, qa$estimate, y = y, x = x, d = d)
@@ -50,10 +50,10 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
     if (nc <= 1) {
       runtime <- proc.time()
       for (i in 1:B) {
-        ida <- sample( 1:n, n, replace = TRUE )
+	    ida <- Rfast2::Sample(n, n, replace = TRUE)
         yb <- y[ida, ]
         xb <- x[ida, ]
-        ini <- as.vector( t( kl.compreg(yb, xb[, -1, drop = FALSE])$be ) ) ## initial values
+        ini <- as.vector( t( Compositional::kl.compreg(yb, xb[, -1, drop = FALSE], con = con)$be ) ) ## initial values
         qa <- nlm(jsreg, ini, y = yb, x = xb, d = d)
         qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
         qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
@@ -64,16 +64,16 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
     } else {
       runtime <- proc.time()
-	  oop <- options(warn = -1)
-      on.exit( options(oop) )
+      #suppressWarnings()
       requireNamespace("doParallel", quietly = TRUE, warn.conflicts = FALSE)
       cl <- parallel::makePSOCKcluster(ncores)
       doParallel::registerDoParallel(cl)
-      betaboot <- foreach::foreach(i = 1:B, .combine = rbind, .export=c("jsreg", "kl.compreg") ) %dopar% {
-        ida <- sample(1:n, n, replace = TRUE)
+      betaboot <- foreach::foreach(i = 1:B, .combine = rbind, .packages = "Rfast2",
+	    .export = c("Sample.int", "jsreg", "kl.compreg") ) %dopar% {
+		  ida <- Rfast2::Sample.int(n, n, replace = TRUE)
         yb <- y[ida, ]
         xb <- x[ida, ]
-        ini <- as.vector( t( kl.compreg(yb, xb[, -1, drop = FALSE])$be ) ) ## initial values
+        ini <- as.vector( t( Compositional::kl.compreg(yb, xb[, -1, drop = FALSE], con = con)$be ) ) ## initial values
         qa <- nlm(jsreg, ini, y = yb, x = xb, d = d)
         qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
         qa <- nlm(jsreg, qa$estimate, y = yb, x = xb, d = d)
@@ -83,7 +83,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
       covb <- cov(betaboot)
       runtime <- proc.time() - runtime
     }  ##  end (nc <= 1) {
-	
+
     nam <- NULL
     for (i in 1:p)  nam <- c(nam, paste(namy, ":", namx[i], sep = "") )
     colnames(covb) <- rownames(covb) <- nam
@@ -91,6 +91,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
   if ( !is.null(xnew) ) {
     xnew <- model.matrix(~., data.frame(xnew) )
+    if ( !con )  xnew <- xnew[, -1, drop = FALSE]
     mu <- cbind( 1, exp(xnew %*% be) )
     est <- mu / Rfast::rowsums(mu)
   }  else  est <- NULL
